@@ -623,8 +623,8 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 cat = 'r'
             else:
                 cat = 'NA'
-            cat_word  = '#'.join([cat_word.split("#")[0],cat,'1'])
-        sp = getSemanticRelatedness(cat_word,tagged_context,style=style)
+            cat_word  = '#'.join([cat_word.split("#")[0],cat])
+        sp = getSemanticRelatedness(cat_word+"#1",tagged_context,style=style)
         if style == 'A' and window == 'A':
             self.PrevSemPred = sp
             self.save()
